@@ -1,4 +1,4 @@
-/* $Id: ForcedMetadataConnector.java 1684016 2015-06-07 10:03:47Z kwright $ */
+/* $Id$ */
 
 /**
 * Licensed to the Apache Software Foundation (ASF) under one or more
@@ -29,7 +29,7 @@ import java.util.*;
 */
 public class ForcedMetadataConnector extends org.apache.manifoldcf.agents.transformation.BaseTransformationConnector
 {
-  public static final String _rcsid = "@(#)$Id: ForcedMetadataConnector.java 1684016 2015-06-07 10:03:47Z kwright $";
+  public static final String _rcsid = "@(#)$Id$";
 
   // Nodes and attributes representing parameters and values.
   // There will be node for every parameter/value pair.
@@ -77,7 +77,7 @@ public class ForcedMetadataConnector extends org.apache.manifoldcf.agents.transf
   * an output description string in order to determine what should be done.
   *@param documentURI is the URI of the document.  The URI is presumed to be the unique identifier which the output data store will use to process
   * and serve the document.  This URI is constructed by the repository connector which fetches the document, and is thus universal across all output connectors.
-  *@param outputDescription is the description string that was constructed for this document by the getOutputDescription() method.
+  *@param pipelineDescription is the description string that was constructed for this document by the getOutputDescription() method.
   *@param document is the document data to be processed (handed to the output data store).
   *@param authorityNameString is the name of the authority responsible for authorizing any access tokens passed in with the repository document.  May be null.
   *@param activities is the handle to an object that the implementer of a pipeline connector may use to perform operations, such as logging processing activity,
@@ -344,7 +344,7 @@ public class ForcedMetadataConnector extends org.apache.manifoldcf.agents.transf
   
   /** Output the specification body section.
   * This method is called in the body section of a job page which has selected a pipeline connection of the current type.  Its purpose is to present the required form elements for editing.
-  * The coder can presume that the HTML that is output from this configuration will be within appropriate <html>, <body>, and <form> tags.  The name of the
+  * The coder can presume that the HTML that is output from this configuration will be within appropriate &lt;html&gt;, &lt;body&gt;, and &lt;form&gt; tags.  The name of the
   * form is "editjob".
   *@param out is the output to which any HTML should be sent.
   *@param locale is the preferred local of the output.
@@ -485,7 +485,7 @@ public class ForcedMetadataConnector extends org.apache.manifoldcf.agents.transf
   
   /** View specification.
   * This method is called in the body section of a job's view page.  Its purpose is to present the pipeline specification information to the user.
-  * The coder can presume that the HTML that is output from this configuration will be within appropriate <html> and <body> tags.
+  * The coder can presume that the HTML that is output from this configuration will be within appropriate &lt;html&gt; and &lt;body&gt;tags.
   *@param out is the output to which any HTML should be sent.
   *@param locale is the preferred local of the output.
   *@param connectionSequenceNumber is the unique number of this connection within the job.
@@ -513,7 +513,7 @@ public class ForcedMetadataConnector extends org.apache.manifoldcf.agents.transf
     final Map<String,Set<String>> additions = new HashMap<String,Set<String>>();
     
     String keepAllMetadataValue = "true";
-    String filterEmptyValue = "false";
+    String filterEmptyValue = "true";
     for (int i = 0; i < os.getChildCount(); i++)
     {
       SpecificationNode sn = os.getChild(i);
@@ -734,7 +734,7 @@ public class ForcedMetadataConnector extends org.apache.manifoldcf.agents.transf
 
     public SpecPacker(Specification os) {
       boolean keepAllMetadata = true;
-      boolean filterEmpty = false;
+      boolean filterEmpty = true;
       final Map<String,Set<String>> additions = new HashMap<String,Set<String>>();
       final Map<String,Set<String>> expressionAdditions = new HashMap<String,Set<String>>();
       for (int i = 0; i < os.getChildCount(); i++) {
